diff -urw ../osso-xterm-0.14.mh30+0m5/src/terminal-gconf.h ./src/terminal-gconf.h
--- ../osso-xterm-0.14.mh30+0m5/src/terminal-gconf.h	2009-09-24 10:36:54.000000000 +0100
+++ ./src/terminal-gconf.h	2011-03-05 23:11:55.000000000 +0000
@@ -47,6 +47,13 @@
 #define OSSO_XTERM_GCONF_BG_COLOR    OSSO_XTERM_GCONF_PATH "/background"
 #define OSSO_XTERM_DEFAULT_BG_COLOR  "#FFFFFF"
 
+#define OSSO_XTERM_GCONF_PALETTE    OSSO_XTERM_GCONF_PATH "/palette"
+#define OSSO_XTERM_DEFAULT_PALETTE \
+  "#000000,#c00000,#00c000,#c0c000," \
+  "#0000c0,#c000c0,#00c0c0,#c0c0c0," \
+  "#000000,#ff3f3f,#3fff3f,#ffff3f," \
+  "#3f3fff,#ff3fff,#3fffff,#ffffff"
+
 /* Int */
 #define OSSO_XTERM_GCONF_SCROLLBACK  OSSO_XTERM_GCONF_PATH "/scrollback"
 #define OSSO_XTERM_DEFAULT_SCROLLBACK 200
diff -urw ../osso-xterm-0.14.mh30+0m5/src/terminal-widget.c ./src/terminal-widget.c
--- ../osso-xterm-0.14.mh30+0m5/src/terminal-widget.c	2009-07-22 12:38:20.000000000 +0100
+++ ./src/terminal-widget.c	2011-03-06 00:13:38.000000000 +0000
@@ -154,7 +154,8 @@
 static void     terminal_widget_update_colors		      (TerminalWidget *widget,
 							       const gchar *fg_name,
 							       const gchar *bg_name,
-                                                               gboolean reverse);
+							       gboolean reverse,
+							       const gchar *palette);
 #if 0
 static void     terminal_widget_timer_background_destroy      (gpointer        user_data);
 #endif
@@ -1233,16 +1234,27 @@
 }
 
 static void
-terminal_widget_update_colors (TerminalWidget *widget, const gchar *fg_name, const gchar *bg_name, gboolean reverse)
+terminal_widget_update_colors (TerminalWidget *widget, const gchar *fg_name, const gchar *bg_name, gboolean reverse, const gchar *palette_names)
 {
   GdkColor fg, bg;
+  gchar **palette_names_split;
+  int i;
+  GdkColor palette[16];
+  int palette_size = 0;
 
   gdk_color_parse(fg_name, &fg);
   gdk_color_parse(bg_name, &bg);
 
+  palette_names_split = g_strsplit(palette_names, ",", 16);
+  for(i = 0; palette_names_split[i] != NULL; i++) {
+    gdk_color_parse(palette_names_split[i], &palette[i]);
+    palette_size++;
+  }
+  g_strfreev(palette_names_split);
+
   vte_terminal_set_colors(VTE_TERMINAL(widget->terminal),
 			  (reverse ? &bg : &fg), (reverse ? &fg : &bg),
-			  NULL, 0);
+			  palette, palette_size);
 }
 
 
@@ -1318,11 +1330,13 @@
                               TerminalWidget *widget) {
   gchar *fg_name;
   gchar *bg_name;
+  gchar *palette;
   gboolean reverse;
   GConfValue *reverse_value;
 
   fg_name = gconf_client_get_string(client, OSSO_XTERM_GCONF_FONT_COLOR, NULL);
   bg_name = gconf_client_get_string(client, OSSO_XTERM_GCONF_BG_COLOR, NULL);
+  palette = gconf_client_get_string(client, OSSO_XTERM_GCONF_PALETTE, NULL);
   reverse_value = gconf_client_get(client, OSSO_XTERM_GCONF_REVERSE, NULL);
   if (reverse_value) {
     if (reverse_value->type == GCONF_VALUE_BOOL) {
@@ -1341,11 +1355,15 @@
   if (!bg_name) {
     bg_name = g_strdup(OSSO_XTERM_DEFAULT_BG_COLOR);
   }
+  if (!palette) {
+    palette = g_strdup(OSSO_XTERM_DEFAULT_PALETTE);
+  }
 
-  terminal_widget_update_colors(widget, fg_name, bg_name, reverse);
+  terminal_widget_update_colors(widget, fg_name, bg_name, reverse, palette);
 
   g_free(fg_name);
   g_free(bg_name);
+  g_free(palette);
 }
 
 
